==> LivestockCV-0.0.0.24-py3-none-any.whl: LivestockCV/core/__init__.py <==
import os
import matplotlib
from LivestockCV.core.fatal_error import fatal_error
from LivestockCV.core.classes import Params
from LivestockCV.core.classes import Outputs

params = Params()
outputs = Outputs()

from LivestockCV.core.deprecation_warning import deprecation_warning
from LivestockCV.core.print_image import print_image
from LivestockCV.core.plot_image import plot_image
from LivestockCV.core.color_palette import color_palette
from LivestockCV.core.rgb2gray import rgb2gray
from LivestockCV.core.rgb2gray_hsv import rgb2gray_hsv
from LivestockCV.core.rgb2gray_lab import rgb2gray_lab
from LivestockCV.core import transform
from LivestockCV.core.apply_mask import apply_mask
from LivestockCV.core.crop import crop
from LivestockCV.core.invert import invert
from LivestockCV.core import roi
from LivestockCV.core import threshold
from LivestockCV.core.gaussian_blur import gaussian_blur
from LivestockCV.core.analyze_color import analyze_color
from LivestockCV.core.frame_count import frame_count
from LivestockCV.core import box
from LivestockCV.core import java_convert
from LivestockCV.core import snaphoto
from LivestockCV.core import facedetection
# add new functions to end of lists

# Auto versioning
from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'box', 'java_convert', 'snaphoto','facedetection']

==> LivestockCV-0.0.0.32-py3-none-any.whl: LivestockCV/core/__init__.py <==
import os
import matplotlib
from LivestockCV.core.fatal_error import fatal_error
from LivestockCV.core.classes import Params
from LivestockCV.core.classes import Outputs

params = Params()
outputs = Outputs()

from LivestockCV.core.deprecation_warning import deprecation_warning
from LivestockCV.core.print_image import print_image
from LivestockCV.core.plot_image import plot_image
from LivestockCV.core.color_palette import color_palette
from LivestockCV.core.rgb2gray import rgb2gray
from LivestockCV.core.rgb2gray_hsv import rgb2gray_hsv
from LivestockCV.core.rgb2gray_lab import rgb2gray_lab
from LivestockCV.core import transform
from LivestockCV.core.apply_mask import apply_mask
from LivestockCV.core.crop import crop
from LivestockCV.core.invert import invert
from LivestockCV.core.rotate import rotate
from LivestockCV.core import roi
from LivestockCV.core import threshold
from LivestockCV.core.gaussian_blur import gaussian_blur
from LivestockCV.core.analyze_color import analyze_color
from LivestockCV.core.frame_count import frame_count
from LivestockCV.core import js_to_image
from LivestockCV.core import bbox_to_bytes
from LivestockCV.core import take_photo
# add new functions to end of lists

# Auto versioning
from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'rotate', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo']
